import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:openmediacentermobile/api/api.dart';

import 'log/log.dart';
import 'platform.dart';
import 'preview_tile.dart';
import 'package:flutter_staggered_grid_view/flutter_staggered_grid_view.dart';

class VideoFeed extends StatefulWidget {
  const VideoFeed({Key? key}) : super(key: key);

  @override
  State<StatefulWidget> createState() {
    return VideoFeedState();
  }
}

class VideoFeedState extends State<VideoFeed> {
  late Future<List<VideoT>> _data;

  Future<List<VideoT>> loadData() async {
    final data = await API.query("video", "getMovies", {'Tag': 1, 'Sort': 0});

    final d = jsonDecode(data);

    List<VideoT> dta = (d['Videos'] as List).map((e) => VideoT.fromJson(e)).toList();

    return dta;
  }

  @override
  void initState() {
    super.initState();

    _data = loadData();
  }

  @override
  Widget build(BuildContext context) {
    double width = MediaQuery.of(context).size.width;
    Log.d(width);

    return FutureBuilder<List<VideoT>>(
      future: _data, // a previously-obtained Future<String> or null
      builder: (BuildContext context, AsyncSnapshot<List<VideoT>> snapshot) {
        if (snapshot.hasError) {
          return Text("Error");
        } else if (snapshot.hasData) {
          return MasonryGridView.count(
            // every tile should be at max 330 pixels long...
            crossAxisCount: isTV() ? width ~/ 200 : width ~/ 330,
            mainAxisSpacing: 4,
            crossAxisSpacing: 4,
            itemBuilder: (context, index) {
              return PreviewTile(dta: snapshot.data![index]);
            },
          );
        } else {
          return Column(children: const <Widget>[
            SizedBox(
              width: 60,
              height: 60,
              child: CircularProgressIndicator(),
            ),
            Padding(
              padding: EdgeInsets.only(top: 16),
              child: Text('Awaiting result...'),
            )
          ]);
        }
      },
    );
  }
}
